==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/Entity.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Entity extends io.intino.sumus.graph.Record {

	protected java.util.List<io.intino.sumus.graph.Entity> entityList = new java.util.ArrayList<>();

	public Entity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return java.util.Collections.unmodifiableList(entityList);
	}

	public io.intino.sumus.graph.Entity entity(int index) {
		return entityList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList(java.util.function.Predicate<io.intino.sumus.graph.Entity> predicate) {
		return entityList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	public io.intino.sumus.graph.dynamic.DynamicEntity asDynamic() {
		return a$(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public io.intino.sumus.graph.dynamic.DynamicEntity asDynamic(java.time.Instant created) {
		io.intino.sumus.graph.dynamic.DynamicEntity newElement = core$().addFacet(io.intino.sumus.graph.dynamic.DynamicEntity.class);
		newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
	    return newElement;
	}

	public boolean isDynamic() {
		return core$().is(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public void removeDynamic() {
		core$().removeFacet(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public io.intino.sumus.graph.aspect.AspectEntity asAspect() {
		io.intino.tara.magritte.Layer as = a$(io.intino.sumus.graph.aspect.AspectEntity.class);
		return as != null ? (io.intino.sumus.graph.aspect.AspectEntity) as : core$().addFacet(io.intino.sumus.graph.aspect.AspectEntity.class);
	}

	public boolean isAspect() {
		return core$().is(io.intino.sumus.graph.aspect.AspectEntity.class);
	}

	public io.intino.sumus.graph.geolocated.GeolocatedEntity asGeolocated() {
		return a$(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	public io.intino.sumus.graph.geolocated.GeolocatedEntity asGeolocated(double x, double y) {
		io.intino.sumus.graph.geolocated.GeolocatedEntity newElement = core$().addFacet(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
		newElement.core$().set(newElement, "x", java.util.Collections.singletonList(x));
		newElement.core$().set(newElement, "y", java.util.Collections.singletonList(y));
	    return newElement;
	}

	public boolean isGeolocated() {
		return core$().is(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	public void removeGeolocated() {
		core$().removeFacet(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	public io.intino.sumus.graph.lock.LockEntity asLock() {
		return a$(io.intino.sumus.graph.lock.LockEntity.class);
	}

	public io.intino.sumus.graph.lock.LockEntity asLock(java.lang.String value) {
		io.intino.sumus.graph.lock.LockEntity newElement = core$().addFacet(io.intino.sumus.graph.lock.LockEntity.class);
		newElement.core$().set(newElement, "value", java.util.Collections.singletonList(value));
	    return newElement;
	}

	public boolean isLock() {
		return core$().is(io.intino.sumus.graph.lock.LockEntity.class);
	}

	public void removeLock() {
		core$().removeFacet(io.intino.sumus.graph.lock.LockEntity.class);
	}

	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(entityList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Entity")) this.entityList.add(node.as(io.intino.sumus.graph.Entity.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Entity")) this.entityList.remove(node.as(io.intino.sumus.graph.Entity.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Record.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.0.3-sources.jar: io/intino/sumus/graph/Entity.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Entity extends io.intino.sumus.graph.Record {

	protected java.util.List<io.intino.sumus.graph.Entity> entityList = new java.util.ArrayList<>();

	public Entity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return java.util.Collections.unmodifiableList(entityList);
	}

	public io.intino.sumus.graph.Entity entity(int index) {
		return entityList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList(java.util.function.Predicate<io.intino.sumus.graph.Entity> predicate) {
		return entityList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	public io.intino.sumus.graph.dynamic.DynamicEntity asDynamic() {
		return a$(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public io.intino.sumus.graph.dynamic.DynamicEntity asDynamic(java.time.Instant created) {
		io.intino.sumus.graph.dynamic.DynamicEntity newElement = core$().addFacet(io.intino.sumus.graph.dynamic.DynamicEntity.class);
		newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
	    return newElement;
	}

	public boolean isDynamic() {
		return core$().is(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public void removeDynamic() {
		core$().removeFacet(io.intino.sumus.graph.dynamic.DynamicEntity.class);
	}

	public io.intino.sumus.graph.aspect.AspectEntity asAspect() {
		io.intino.tara.magritte.Layer as = a$(io.intino.sumus.graph.aspect.AspectEntity.class);
		return as != null ? (io.intino.sumus.graph.aspect.AspectEntity) as : core$().addFacet(io.intino.sumus.graph.aspect.AspectEntity.class);
	}

	public boolean isAspect() {
		return core$().is(io.intino.sumus.graph.aspect.AspectEntity.class);
	}

	public io.intino.sumus.graph.geolocated.GeolocatedEntity asGeolocated() {
		return a$(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	public io.intino.sumus.graph.geolocated.GeolocatedEntity asGeolocated(double x, double y) {
		io.intino.sumus.graph.geolocated.GeolocatedEntity newElement = core$().addFacet(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
		newElement.core$().set(newElement, "x", java.util.Collections.singletonList(x));
		newElement.core$().set(newElement, "y", java.util.Collections.singletonList(y));
	    return newElement;
	}

	public boolean isGeolocated() {
		return core$().is(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	public void removeGeolocated() {
		core$().removeFacet(io.intino.sumus.graph.geolocated.GeolocatedEntity.class);
	}

	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(entityList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Entity")) this.entityList.add(node.as(io.intino.sumus.graph.Entity.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Entity")) this.entityList.remove(node.as(io.intino.sumus.graph.Entity.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Record.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
